/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_DOMAIN_H__
#define __TK_DOMAIN_H__

#include <map>

#include <boost/assign/list_of.hpp>
#include <gtkmm.h>

#include "libtkcommon/tkstring.h"

#include "editor/domain.h"

namespace Tk {
  namespace Editor {
    
    typedef std::map<Tk::String, Tk::String> DomainMap;
    
    const DomainMap domains = boost::assign::map_list_of
      ("experiment", "Experiment")
      ("operator",   "Operator")
      ("location",   "Location");
    
    const Tk::String &get_domain_label(const Tk::String &domain);
    
    class Domain : public Gtk::ComboBox
      {
      private:
	class Columns : public Gtk::TreeModelColumnRecord
	  {
	  public:
	    Columns()
	    { add(_name); add(_label); }
	    
	    Gtk::TreeModelColumn<Tk::String>    _name;
	    Gtk::TreeModelColumn<Glib::ustring> _label;
	  };
	
	Columns                       _columns;
	Glib::RefPtr<Gtk::ListStore>  _store;
	
      public:
	typedef sigc::signal<void, const Tk::String &> SignalDomainChanged;
	
	SignalDomainChanged signal_domain_changed();
	
      protected:
	SignalDomainChanged _signal_domain_changed;
	virtual void on_changed();
      public:
	Domain();
	Tk::String get_domain() const;
      };
    
    
  } /* namespace Editor */
}; /* namespace Tk */

#endif /* __TK_DOMAIN_H__ */
