/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "editor/editor.h"

using namespace Tk::Editor;

Editor:: Editor(Db::Database *database)
  : Gtk::Window(),
    _database(database),
    _domain(),
    _constraint(database, _domain),
    _item_tree(database, _domain, _constraint)
{
  WDEBUG_OUT << L"initialising Editor" << std::endl;
  set_title("TkResolver++ Data Editor");
  set_default_size(800, 600);
  set_position(Gtk::WIN_POS_CENTER);
  
  Gtk::VBox *main_box( Gtk::manage(new Gtk::VBox) );
  add(*main_box);
  
  // top bar
  Gtk::HBox *top_box( Gtk::manage(new Gtk::HBox) );
  main_box->pack_start(*top_box, false, true);
  
  top_box->pack_start(_domain, false, true);
  top_box->pack_start(_constraint, true, true);
  
  // tree and item area
  Gtk::HPaned *item_panes( Gtk::manage(new Gtk::HPaned) );
  main_box->pack_start(*item_panes, true, true);
  
  Gtk::VBox *item_tree_box( Gtk::manage(new Gtk::VBox) );
  item_panes->add1(*item_tree_box);
  
  item_tree_box->pack_start(_item_tree, true, true);
  
  Gtk::Button *create_button( Gtk::manage(new Gtk::Button("Create")) );
  item_tree_box->pack_start(*create_button, false, false);
  _item_tree.connect_create_button(*create_button);
  
  show_all_children();
  show();
  
  WDEBUG_OUT << L"finished initialising Editor" << std::endl;
}
