/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "editor/item_store.h"

using namespace Tk::Editor;

//static ItemStoreColumns columns;

ItemStore:: ItemStore(Tk::Db::Database *database, const Tk::String &domain)
  : _database(database),
    _domain(domain),
    _cell_data_slot( sigc::mem_fun(*this, &ItemStore::on_cell_data) )
{
  WDEBUG_OUT << L"initialising ItemStore" << std::endl;
  
  set_column_types(_columns);

  WDEBUG_OUT << L"set column types; getting entities.." << std::endl;

  Tk::Db::IdList ids( Tk::Query::get_all_entities(database, _domain) );
  
  WDEBUG_OUT << L"..got entities; setting entities.." << std::endl;
  
  set_entities(ids);
  
  WDEBUG_OUT << L"initialised ItemStore" << std::endl;
}

void
ItemStore:: set_entities(const Tk::Db::IdList &ids)
{
  WDEBUG_OUT << L"setting entities" << std::endl;

  /* Add new IDs */
  for (Tk::Db::IdList::const_iterator id_iter( ids.begin() ); id_iter != ids.end(); ++id_iter)
    {
      bool found(false);
      Tk::Db::Id id(*id_iter);
      for (Gtk::TreeIter tree_iter( get_iter("0") ); tree_iter; ++tree_iter)
	{
	  if (tree_iter->get_value(_columns.id) == id)
	    {
	      found = true;
	      break;
	    }
	}
      
      if (!found)
	{
	  Gtk::TreeIter row( append() );
	  
	  row->set_value<Tk::Db::Id>(_columns.id, id);
	  row->set_value<Item *>(_columns.item, create_item(id));
	  
	}
    }
  
  /* Remove old IDs */
  for (Gtk::TreeIter tree_iter( get_iter("0") ); tree_iter; ++tree_iter)
    {
      bool found(false);
      Tk::Db::Id tree_id(tree_iter->get_value(_columns.id));
      for (Tk::Db::IdList::const_iterator id_iter( ids.begin() ); id_iter != ids.end(); ++id_iter)
	{
	  if (tree_id == *id_iter)
	    {
	      found = true;
	      break;
	    }
	}
      
      if (!found)
	{ 
	  Gtk::TreeIter prev(tree_iter);
	  --prev;
	  
	  erase(tree_iter);
	  
	  tree_iter = prev;
	}
    }
  
  WDEBUG_OUT << L"set entities" << std::endl;
}

void
ItemStore:: set_constraint(const Tk::Query::Query &query)
{
  set_entities(query.get_entities(_domain));
}

void
ItemStore:: on_cell_data(Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
{
  dynamic_cast<Gtk::CellRendererText *>(cell)->property_text() = iter->get_value(_columns.item)->get_store_cell_text();
}

const Gtk::TreeViewColumn::SlotCellData &
ItemStore:: get_cell_data_slot()
{
  return _cell_data_slot;
}

const Tk::String &
ItemStore:: get_domain() const
{
  return _domain;
}
