/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdexcept>

#include "editor/item_tree.h"
#include "editor/domain.h"
#include "editor/experiment_store.h"
#include "editor/location_store.h"

using namespace Tk::Editor;

ItemTree:: ItemTree(Tk::Db::Database *database, Domain &domain, Constraint &constraint)
  : _database(database)
{
  WDEBUG_OUT << L"initialising ItemTree" << std::endl;

  WDEBUG_OUT << L"creating store.." << std::endl;
  ExperimentStore *ex(new ExperimentStore(database));
  WDEBUG_OUT << L"..created store, adding.." << std::endl;
  add_store("experiment", ex);
  WDEBUG_OUT << L"..added store" << std::endl;

  add_store("location", new LocationStore(database));
  
  set_domain(domain.get_domain());
  domain.signal_domain_changed().connect( sigc::mem_fun(*this, &ItemTree::set_domain) );
  
  constraint.signal_constraint_activated().connect( sigc::mem_fun(*this, &ItemTree::set_constraint) );
  
  append_column(_column);

  WDEBUG_OUT << L"initialised ItemTree" << std::endl;
}

void
ItemTree:: add_store(const Tk::String &domain, ItemStore *item_store)
{
  Glib::RefPtr<ItemStore> item_store_ptr(item_store);
  _stores.insert(DomainItemStores::value_type(domain, item_store_ptr));
}

void
ItemTree:: connect_create_button(Gtk::Button &create_button)
{
  create_button.signal_clicked().connect( sigc::mem_fun(*this, &ItemTree::create) );
}


void
ItemTree:: set_domain(const Tk::String &domain)
{
  DomainItemStores::iterator iter( _stores.find(domain) );
  
  if (iter == _stores.end())
    throw std::runtime_error(std::string("Could not find item store for domain `") + static_cast<std::string>(domain) + "'");
  
  _current = iter->second;
  
  set_model(_current);
  
  _column.set_title(get_domain_label(domain));
  _column.set_cell_data_func(_renderer, _current->get_cell_data_slot());
}

void
ItemTree:: set_constraint(const Tk::Query::Query &query)
{
  _current->set_constraint(query);
}

ItemTree::SignalItemView
ItemTree:: signal_item_view()
{
  return _signal_item_view;
}


void
ItemTree:: create()
{
  Tk::String domain( _current->get_domain() );
  Tk::Db::Id entity_id( _database->create_entity(domain) );
  
  Glib::RefPtr<ItemView> view( new ItemView(_database, domain, entity_id) );
  
  _signal_item_view.emit(view);
}
