/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_ITEM_TREE_H__
#define __TK_ITEM_TREE_H__

#include <map>

#include <gtkmm.h>

#include "libtkcommon/tkstring.h"

#include "editor/domain.h"
#include "editor/constraint.h"
#include "editor/item_store.h"
#include "editor/item_view.h"

namespace Tk {
  namespace Editor {
    
    class ItemTree : public Gtk::TreeView
      {
	/* domain -> item store */
	typedef std::map<Tk::String, Glib::RefPtr<ItemStore> > DomainItemStores;
	
	Tk::Db::Database       *_database;
	DomainItemStores        _stores;
	Glib::RefPtr<ItemStore> _current;
	
	Gtk::CellRendererText   _renderer;
	Gtk::TreeViewColumn     _column;
	
	void add_store(const Tk::String &domain, ItemStore *item_store);
	void create();
      public:
	typedef sigc::signal<void, Glib::RefPtr<ItemView> > SignalItemView;
	
	SignalItemView signal_item_view();
	
      protected:
	SignalItemView _signal_item_view;
	
      public:
	ItemTree(Tk::Db::Database *database, Domain &domain, Constraint &constraint);
	void connect_create_button(Gtk::Button &create_button);
	void set_domain(const Tk::String &domain);
	void set_constraint(const Tk::Query::Query &query);
      };
    
    
  } /* namespace Editor */
}; /* namespace Tk */

#endif /* __TK_ITEM_TREE_H__ */
