/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_EXPERIMENTER_H__
#define __TK_EXPERIMENTER_H__

#include <gtkmm.h>

#include "libtkresolver/tkresolver.h"
#include "parameters.h"
#include "location_selector.h"
#include "operator_selector.h"
#include "text_frame.h"
#include "flash_toggle_tool.h"

namespace Tk {
  namespace Experimenter {

    
    class Experimenter : public Gtk::Window
      {
      private:
	SDL                   _sdl;
	Db::Database         *_database;

	Gtk::Toolbar          _toolbar;
	FlashToggleTool       _control;
	
	Parameters            _parameters;
	LocationSelector      _location;
	OperatorSelector      _operators;
	TextPtr               _notes;
	
        sigc::connection      _timeout;

	bool get_location_id(Db::Id & location_id, bool interactive = true);
	
	void control_toggle();
	bool control_start();
	bool control_notify();
	void control_stop();
	bool control_exec();

	void control_notify_start();
	void control_notify_stop();
	
	void execute_control();
	void execute_proper(bool test,
			    const Db::IdList & operators,
			    bool control,
			    const String * notes = 0,
			    bool interactive = true);
	void execute_or_test(bool test);
      public:
	Experimenter(Db::Database *database);
	void execute();
	void test();
      };
    
    
  } /* namespace Experimenter */
}; /* namespace Tk */

#endif /* __TK_EXPERIMENTER_H__ */
