/*
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <boost/assign/list_of.hpp>

#include "libtkcommon/mbs.h"
#include "location_selector.h"

using namespace Tk;
using namespace Experimenter;
using namespace Db::Ui;

const static StringList selection_columns = boost::assign::list_of(String("location_id"));
const static StringList location_columns  = boost::assign::list_of(String("name"));
const static ListColumnList display_columns = boost::assign::list_of
  (ListColumnInfo("Location", location_columns, 0));

LocationSelector:: LocationSelector(Db::Database *database,
				    Gtk::Window *parent)
  : DataSelectorInputList<LocationInput>(database,
					 "location",
					 selection_columns,
					 parent,
					 "Location")
{
  DEBUG_OUT << "Initialising LocationSelector..." << std::endl;
  
  
  DEBUG_OUT << "Setting display columns..." << std::endl;
  set_display_columns(display_columns);
  DEBUG_OUT << "...set display columns" << std::endl;
  
  
  DEBUG_OUT << "Setting selection..." << std::endl;
  set_selection<Db::Id>("location_id", database->choose_location());
  DEBUG_OUT << "...set selection" << std::endl;
  
  DEBUG_OUT << "...initialised LocationSelector" << std::endl;
}

Db::Id
LocationSelector:: get_location_id() const
{
  return get_selection<Db::Id>().front()["location_id"];
}



LocationInput:: LocationInput(Gtk::Window &parent)
  : DataInput("Location details", parent) 
{
  Gtk::Table * table = Gtk::manage(new Gtk::Table(3, 2));
  get_vbox()->pack_start(*table, true, true);
  
  table->attach(*Gtk::manage(new Gtk::Label("Name",    Gtk::ALIGN_LEFT)), 0, 1, 0, 1, Gtk::FILL, Gtk::FILL);
  table->attach(*Gtk::manage(new Gtk::Label("Address", Gtk::ALIGN_LEFT)), 0, 1, 1, 2, Gtk::FILL, Gtk::FILL);
  table->attach(*Gtk::manage(new Gtk::Label("Height",  Gtk::ALIGN_LEFT)), 0, 1, 2, 3, Gtk::FILL, Gtk::FILL);
  
  _height.set_numeric(true);
  Gtk::Adjustment * adj = Gtk::manage(new Gtk::Adjustment(0, -10000, 10000));
  _height.set_adjustment(*adj);

  table->attach(_name,    1, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::FILL);
  table->attach(_address, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::FILL);
  table->attach(_height,  1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::FILL);

  show_all_children();
}

StringList
LocationInput:: get_insert_columns()
{
  StringList columns;
  columns.push_back(L"name");
  columns.push_back(L"address");
  columns.push_back(L"height");
  
  return columns;
}

void
LocationInput:: get_values_sub(Db::PStatement &stmt)
{
  stmt.setString(1, String(_name.get_text()));
  stmt.setString(2, String(_address.get_text()));
  stmt.setInt(3,    _height.get_value_as_int());
}
