/*
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007, 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkcommon/debug.h"

#include "variables.h"

using namespace Tk;
using namespace Experimenter;

Variables:: Variables(Db::Database *database,
		      Gtk::Window &parent,
		      unsigned trace_count,
		      const String &algorithm_spec,
		      bool test)
  : Gtk::Dialog("Experiment variables", parent, true),
    _intent_list(database, trace_count, algorithm_spec, test),
    _ability_rating_set("Assess ability"),
    _ability_rating(5.0, 0.0, 10.0, 0.1, 1.0),
    _ability_rating_slider(_ability_rating)
{
  set_default_size(500, 300);
  add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
  add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
  
  /* Intent list */
  get_vbox()->pack_start(_intent_list, true, true);
  
  /* Ability rating */
  Gtk::Frame *ability_frame = manage(new Gtk::Frame("Ability"));
  get_vbox()->pack_start(*ability_frame, false, true);
  
  Gtk::VBox *ability_box = manage(new Gtk::VBox());
  ability_frame->add(*ability_box);
  
  Gtk::Label *ability_blurb = manage(new Gtk::Label(
    "Please assess your psi ability with respect to your current state of mind"
    ));
  ability_blurb->set_line_wrap(true);
  ability_blurb->set_single_line_mode(false);
  ability_blurb->set_justify(Gtk::JUSTIFY_CENTER);
  ability_box->pack_start(*ability_blurb, true, true);
  
  _ability_rating_set.set_active(false);
  _ability_rating_set.signal_toggled().connect( sigc::mem_fun(*this, &Variables::refresh_active) );
  ability_box->pack_start(_ability_rating_set, true, true);

  _ability_rating_slider.set_digits(10);
  refresh_active();
  ability_box->pack_start(_ability_rating_slider, true, true);
  
  show_all_children();
}

void
Variables:: refresh_active()
{
  _ability_rating_slider.set_sensitive( _ability_rating_set.get_active() );
}


Db::Code
Variables:: get_intent_code()
{
  return _intent_list.get_intent_code();
}

Double
Variables:: get_ability_rating()
{
  if (_ability_rating_set.get_active() )
    {
      WDEBUG_OUT << L"value: " << _ability_rating.get_value()
		 << L"; lower: " << _ability_rating.get_lower()
		 << L"; upper: " << _ability_rating.get_upper()
		 << L"; diff: " << (_ability_rating.get_upper() - _ability_rating.get_lower())
		 << L"; rating: " << ((_ability_rating.get_value() - _ability_rating.get_lower())
				      / (_ability_rating.get_upper() - _ability_rating.get_lower()))
		 << std::endl;
      
      return (_ability_rating.get_value() - _ability_rating.get_lower())
	/ (_ability_rating.get_upper() - _ability_rating.get_lower());
    }
  else
    return Double();
}
