/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkdbui/boolean_value.h"

#include "libtkcommon/tkintl.h"

using namespace Tk::Db::Ui;
    
BooleanValue:: BooleanValue(const Tk::Bool &source)
  : _null(Gtk::Stock::APPLY),
    _datum(Gtk::Stock::YES),
    Value(Tk::Db::Data::Boolean)
{
  pack_start(_null, false, false);
  _null.set_tooltip_text(_("Whether or not the boolean datum has a value"));
  
  pack_start(_datum, true, true);
  _datum.set_tooltip_text(_("The boolean value of the datum"));
  
  bool is_null(source.is_null());
  _null.set_active(is_null);
  if (!is_null)
    _datum.set_active(source.get_value());
  
  update_sensitivity();
  
  _null.signal_toggled().connect( sigc::mem_fun(*this, &BooleanValue::changed) );
  _datum.signal_toggled().connect( sigc::mem_fun(*this, &BooleanValue::changed) );
}

void
BooleanValue:: update_sensitivity()
{
  _datum.set_sensitive(!_null.get_active());
}

void
BooleanValue:: changed()
{
  update_sensitivity();
  
  if (_null.get_active())
    emit();
  else
    emit( Tk::Db::Data::Datum( _datum.get_active() ) );
}
