/*
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "data_selector_combo.h"

using namespace Tk;
using namespace Db::Ui;

DataSelectorCombo:: DataSelectorCombo (Db::Database * database,
				       const String & table_name,
				       const StringList & selection_columns)
  : DataSelector(database, table_name, selection_columns)
{
}

void
DataSelectorCombo:: set_display_columns(const ComboColumnList & display_columns)
{
  set_columns(display_column_names(display_columns));

  const Glib::RefPtr<Gtk::ListStore> & store(get_store());
  set_model(store);

  for (ComboColumnList::const_iterator iter(display_columns.begin());
       iter != display_columns.end();
       ++iter)
    {
      ComboColumnAdaptor adaptor(this);
      create_view_cell(*iter, adaptor);
    }

  show_all_children();

  set_active(store->get_iter(Gtk::TreePath("0")));
}


ModelIteratorList
DataSelectorCombo:: get_selected() const
{
  if (get_active_row_number() == -1)
    throw NoSelection();
  
  ModelIteratorList list;
  list.push_back(get_active());
  return list;
}

void
DataSelectorCombo:: refreshed()
{
  0;
}

void
DataSelectorCombo:: select(Gtk::TreeModel::iterator &iter)
{
  set_active(iter);
}
