/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_DB_UI_DATA_SELECTOR_LIST_H__
#define __TK_DB_UI_DATA_SELECTOR_LIST_H__

#include <gtkmm.h>

#include "data_selector.h"

namespace Tk {
  namespace Db {
    namespace Ui {

      typedef Gtk::TreeViewColumn::SlotCellData SlotListCellData;
      typedef DisplayColumnInfo<SlotListCellData> ListColumnInfo;
      typedef std::list<ListColumnInfo> ListColumnList;
      typedef DisplayColumnAdaptor<Gtk::TreeViewColumn> ListColumnAdaptor;
      
      void append_selection(const Gtk::TreeModel::iterator & iter, ModelIteratorList * list);
      
      class DataSelectorList : public DataSelector, public Gtk::Frame
	{
	private:
	  Gtk::ScrolledWindow                   _view_scroll;
	  Gtk::TreeView                         _view;
	  Gtk::HBox                             _box;
	  
	  void create_widgets(const ListColumnList & display_columns);
	protected:
	  
	  DataSelectorList(Db::Database * database,
			   const String &table_name,
			   const StringList &selection_columns,
			   const String &title);
	  // should be called immediately after constructor
	  void set_display_columns(const ListColumnList & display_columns);

	  Gtk::TreeView & get_view();
	  Gtk::HBox & get_box();
	  virtual ModelIteratorList get_selected() const;
	  virtual void select(Gtk::TreeModel::iterator &iter);
	};

    } /* namespace Ui */
  } /* namespace Db */
}; /* namespace Tk */




#endif /* __TK_DB_UI_DATA_SELECTOR_LIST_H__ */
