/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <limits>
#include <boost/variant/apply_visitor.hpp>

#include "libtkdbui/numeric_value.h"
#include "libtkdb/database.h"

using namespace Tk::Db::Ui;

class SpinSetter
  : public boost::static_visitor<>
{
private:
  Gtk::SpinButton *_spin;
public:
  SpinSetter(Gtk::SpinButton *spin) : _spin(spin) {}
  void operator()(const bool &v)               { throw std::invalid_argument("Cannot set NumericValue from bool"); }
  void operator()(const int &v)                { _spin->set_value(v); }
  void operator()(const unsigned &v)           { _spin->set_value(v); }
  void operator()(const double &v)             { _spin->set_value(v); }
  void operator()(const Tk::String &v)         { throw std::invalid_argument("Cannot set NumericValue from Tk::String"); }
  void operator()(const Tk::Db::DateTime &v)   { throw std::invalid_argument("Cannot set NumericValue from Tk::Db::DateTime"); }
  void operator()(const Tk::Db::Date &v)       { throw std::invalid_argument("Cannot set NumericValue from Tk::Db::Date"); }
};

NumericValue:: NumericValue(const Tk::Db::Data::Value &value)
  : _adjustment(0.0, 0.0, 1.0),
    Value(value.get_type()),
    Gtk::SpinButton(_adjustment)
{
  set_numeric(false);
  
  switch (value.get_type())
    {
    case Tk::Db::Data::Integer:
      _adjustment.set_lower(std::numeric_limits<int>::min());
      _adjustment.set_upper(std::numeric_limits<int>::max());
      break;
    case Tk::Db::Data::Unsigned:
      _adjustment.set_lower(std::numeric_limits<unsigned>::min());
      _adjustment.set_upper(std::numeric_limits<unsigned>::max());
      break;
    case Tk::Db::Data::Double:
      _adjustment.set_lower(std::numeric_limits<double>::min());
      _adjustment.set_upper(std::numeric_limits<double>::max());
      set_digits(5);
      break;
    default:
      throw Tk::Db::UnknownType(static_cast<int>(value.get_type()));
    }
  
  const Tk::Db::Data::Datum &d(value.get_datum());
  if (d.is_null())
    set_text("");
  else
    {
      SpinSetter ss(this);
      boost::apply_visitor(ss, d.get_value());
    }
}
