/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkdbui/value.h"
#include "libtkdbui/boolean_value.h"
#include "libtkdb/database.h"

using namespace Tk::Db::Ui;

Value:: Value(Tk::Db::Data::Type type)
  : _type(type)
{
}

void
Value:: emit(const Tk::Db::Data::Datum &datum)
{
  _signal_value_changed.emit(Tk::Db::Data::Value(_type, datum));
}

Value::SignalValueChanged
Value:: signal_value_changed()
{
  return _signal_value_changed;
}

Value *
Value:: create(const Tk::Db::Data::Value &source)
{
  using namespace Tk::Db::Data;
  switch(source.get_type())
    {
    case Boolean: return new BooleanValue(source.get_value<bool>());
    case Integer: return new IntegerValue(source.get_value<int>());
    case Unsigned: return new UnsignedValue(source.get_value<unsigned>());
    case Double: return new DoubleValue(source.get_value<int>(double));
    case String: return new StringValue(source.get_value<int>(Tk::String));
    case DateTime: return new DateTimeValue(source.get_value<int>(Tk::Db::DateTime));
    case Date: return new DateValue(source.get_value<int>(Tk::Db::Date));
    default: throw Tk::Db::UnknownType(static_cast<int>(source.get_type()));
    }
}

Value *
Value:: create(const Tk::Db::Data::Type &type)
{
  using namespace Tk::Db::Data;
  switch(type)
    {
    case Boolean: return new BooleanValue();
    case Integer: return new IntegerValue();
    case Unsigned: return new UnsignedValue();
    case Double: return new DoubleValue();
    case String: return new StringValue();
    case DateTime: return new DateTimeValue();
    case Date: return new DateValue();
    default: throw Tk::Db::UnknownType(static_cast<int>(type));
    }
}
